@@ -60,8 +60,8 @@ See F<LICENSE>.
 
 =cut
 
-$^V eq 5.32.1 
-    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
+$^V eq 5.34.0 
+    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                    "that PAR::Packer was built with; please rebuild PAR::Packer", 
                    $^X, $^V);
 
@@ -81,8 +81,8 @@ M````/)8````````\E@```````#R6````````#`$````````,`0````````0`
 M````````4>5T9`8`````````````````````````````````````````````
 M````````````$`````````!2Y71D!````#"K````````,*L!```````PJP$`
 M`````-`$````````T`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
-M8V@V-"YS;RXQ```$````%`````,```!'3E4`.*3[L7N7]9Y0Z4)G?[F+EE7:
-MVS@$````$`````$```!'3E4```````,````'`````````#T```!+````!```
+M8V@V-"YS;RXQ```$````%`````,```!'3E4`%L\D[,:"`VH"`S:WTS\*BD>O
+M?'<$````$`````$```!'3E4```````,````'`````````#T```!+````!```
 M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(H!!%N@`""```````````
 M2P````````!,````30```$\`````````4`````````!1````4@```%,```!4
 M`````````%4```!7`````````````````````````````````````````%@`
@@ -175,7 +175,7 @@ M7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C
 M<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S
 M:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R
 M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E
-M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`O=7-R+VQI8B]P97)L-2\U+C,R
+M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`O=7-R+VQI8B]P97)L-2\U+C,T
 M+V-O<F5?<&5R;"]#3U)%``````````(``@`"``(``@`"`````@`"``(``@`"
 M``(````"```````"``(````"``````````(``@`"`````P````,``@`"``(`
 M`@`#```````$``(``@`"`````@`"``(``@`````````"`````@````(`````
@@ -237,8 +237,8 @@ M``"P$<9&^1`B-I$@`A_6T```L!'*1OD00C:1(`(?UM```+`1SD;Y$&(VD2`"
 M'];0``"P$=)&^1""-I$@`A_6_7NYJ?T#`)'S4P&IU```L(-R1_GU6P*I]QL`
 M^>*'!*GB(P&19`!`^>0W`/D$`(#2PP``L.%#`9'@7P"YX',!D6-X1_E@`#_6
 MP```L,(``+##``"P0J!'^0#,1_GA`P*J8Z1'^6``/];```"P`#!'^0``0#E@
-M"P`TTP``T-4``+#6``"PM29'^=921_F@`D"YP`(_U@)H4CE"`!\R`F@2.:`"
-M0+G``C_6`VA2.<$``+#B7T"Y8P``,@-H$CDA2$?Y0!``$54,`!$`?'V3(``_
+M"P`TTP``T-4``+#6``"PM29'^=921_F@`D"YP`(_U@(H4CE"`!\R`B@2.:`"
+M0+G``C_6`RA2.<$``+#B7T"Y8P``,@,H$CDA2$?Y0!``$54,`!$`?'V3(``_
 MUN,#`*KF*T#YP```T&0B`I'E7T"Y`CQ`^2$``)#'`$#Y(>`ID2```)```"J1
 M9P0`J8,$`/EB``&IOP0`<2T+`%0A`(#2'R`#U2`,`!'$>&'X(00`D638(/B_
 M``%K;/__5*4,`!&E?'V3=B("D7]H)?C%``"PX@,5*@$``+`$`(#2I;A'^2'`
@@ -246,7 +246,7 @@ M)9'`#D#YH``_UO4#`"H@!@`T=B("D<$``+#WDP&1(2Q'^<`.0/D@`#_6(```
 MD.$#%ZH``""1C0``E(`%`+1S(@*1P0``L"$81_E@#D#Y(``_UL```+``K$?Y
 M```_UI1R1_GA-T#Y@`)`^2```,H@!@"UX`,5*O-30:GU6T*I]QM`^?U[QZC`
 M`U_6P```L-,``-``0$?Y```_UF(B`I%`#`#Y``0`M,$``+#5``"PU@``L"$4
-M1_D@`#_6H"9'^<%21_D``$"Y(``_UA\D*3F8__\7P0``L,`.0/DAY$?Y(``_
+M1_D@`#_6H"9'^<%21_D``$"Y(``_UA_<*#F8__\7P0``L,`.0/DAY$?Y(``_
 MUO4#`"K+__\7P`I`^6```+16"`"4TO__%^$#%ZH@``"0`$`>D5D``)3`"@#Y
 M@/G_M$X(`)3*__\7!02`TK'__Q?!``"P(`"`4B'P1OD@`#_6P```L`!@1_D`
 M`#_67R0#U1T`@-(>`(#2Y0,`JN$#0/GB(P"1Y@,`D<```+``R$?YPP``L&.(
@@ -422,7 +422,7 @@ M`7'!\_]4X`,9*D(`@%(A!X"2X`(_UN$#&JK@`QDJ(@6`TH`#/]:H``#PY@,:
 MJJ6B')'D`Q2J".U&^>`#$ZH'``#0`P``T.?`*9%C8":1`@"`DB$`@%(``3_6
 M&O__%Z```/``8$?Y```_UOU[N:G]`P"1\U,!J;0``/"S``#P]5L"J;8``/#Y
 M:P2IF29'^?=C`ZGWDP&1P7)'^7A21_DB`$#YXC<`^0(`@-(@`T"Y``,_UO4#
-M`*H@`T"Y``,_UN(#`*JCXD(Y````T.$#%ZH`P!^10^0".:GX_Y>```"T`0!`
+M`*H@`T"Y``,_UN(#`*JCPD(Y````T.$#%ZH`P!^10\0".:GX_Y>```"T`0!`
 M.3_$`''`#0!4\?O_EYDF1_EX4D?Y(`-`N0`#/]:D``#P`0``T&,`@%(A0">1
 MA&A'^2(`@%*``#_6]0,`JL`!`+0@`T"Y``,_UJ$*0/FC``#P`@``T$)@)Y%C
 M-$?Y(0!`^6``/]:@"D#Y``!`^0`,0+E`#;`WFB9'^=4``)!Y4D?Y0`-`N2`#
@@ -430,7 +430,7 @@ M/]:D``#P`0``T&,`@%(A@">1A&A'^2(`@%*``#_6^`,`JB`"`+3A`Q>J````
 MT`"`'I'[*P#Y=_C_E_L#`*I``T"Y>PD`M"`#/]8!"T#YHP``\.(#&ZIC-$?Y
 M(0!`^6``/];[*T#YN2("D90F1_ES4D?Y@`)`N6`"/];X`P"J@`)`N6`"/]:C
 M``#P(@"`4@$``-`AH">18Y!'^6``/];A`P"JHP``\.`#&*H"``#00@`HD6,T
-M1_E@`#_6@`)`N6`"/];B`P"JX0,7J@```-``0!Z17^0".4_X_Y<@"P#Y\P,`
+M1_E@`#_6@`)`N6`"/];B`P"JX0,7J@```-``0!Z17\0".4_X_Y<@"P#Y\P,`
 MJ@`#`+2B``#P`3B`4N`#$ZI"_$?Y0``_U@$$`!$_!`!Q!(A1>N$%`%36<D?Y
 MX3=`^<`"0/D@``#*P`0`M?-30:GU6T*I]V-#J?EK1*G]>\>HP`-?U@`$0#E@
 M\O\TD?__%R`'0/E+_?^7(`L`^?,#`*J@_/^UH0``T/LK`/D```"P`"`HD2&4
